function result = exploitation_sigma(Tsigma2r,Nbi,Nmc)

%------------------------------------------------------------------
% This function allows to exploit the results provided by
%       the function unmixing
% 
% INPUT
%       Tsigma2r : The MCMC samples Sigma generated by the Gibbs sampling
%       Nbi   : number of burn-in iterations
%       Nmc   : length of the Markov Chain
%
% OUTPUT
%       result : 1 if the function is correctly used, 0 otherwise
%
%------------------------------------------------------------------

Nr = Nmc - Nbi;

figure

    Tsigmai = Tsigma2r(1,Nbi+1:end);
    xmin = min(Tsigmai)*0.8;
    xmax = max(Tsigmai)*1.2;
    Nc = sqrt(Nmc-Nbi+1); % optimal number of classes for the histogram
    pas = (xmax-xmin)/Nc;
    hi = hist(Tsigmai,xmin:pas:xmax);
    hi = hi/(pas*Nr);
    bar(xmin:pas:xmax,hi)
    set(gca,'ytick',[]);
    set(gca,'fontsize',16)
    axis([xmin xmax 0 max(hi)*1.1]);
    ylabel(['Posterior distribution of \sigma^2']);

 result = 1;
